@@ -5,10 +5,10 @@
 #include <QtDBus>
 
 #include <mbarcode-qt/plugininterfaces.h>
-#include <mbarcode-qt/sinkplugin.h>
-#include <mbarcode-qt/mainwindow.h>
+#include <mbarcode-qt/pluginaction.h>
+#include <mbarcode-qt/maemobarcodewindow.h>
 
-void ISBNPlugin::initInterface(MainWindow *parent)
+void ISBNPlugin::initInterface(QWidget *parent)
 {
     sink = new ISBNSink(this);
     QWidget* widget = parent;
@@ -16,9 +16,9 @@ void ISBNPlugin::initInterface(MainWindow *parent)
             sink, SLOT(barcodeAnalysed(QString,QString)));
 }
 
-QSet<SinkPlugin*> ISBNPlugin::getSinkPlugins()
+QSet<PluginAction*> ISBNPlugin::getPluginActions()
 {
-    QSet<SinkPlugin*> newList;
+    QSet<PluginAction*> newList;
     newList.insert(sink);
     return newList;
 }
@@ -26,7 +26,7 @@ QSet<SinkPlugin*> ISBNPlugin::getSinkPlugins()
 Q_EXPORT_PLUGIN2(mbqt_qrplugin, ISBNPlugin)
 
 
-ISBNSink::ISBNSink(const PluginInterface *interface) : SinkPlugin(interface)
+ISBNSink::ISBNSink(const PluginInterface *interface) : PluginAction(interface)
 {
     ready = false;
 }
